typedcols
================================================================================

Python 2 and 3 compatible library providing typed collections.

This README file is work in progress, for more information please visit home page
at https://idea.cesnet.cz/en/index.
